"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
exports.fieldValid = fieldValid;
exports.isChrome = isChrome;
exports.isDeg = isDeg;
exports.isEmail = isEmail;
exports.isEven = isEven;
exports.isHSB = isHSB;
exports.isHex = isHex;
exports.isInRange = isInRange;
exports.isInteger = isInteger;
exports.isMac = isMac;
exports.isNegativeInteger = isNegativeInteger;
exports.isNonnegativeInteger = isNonnegativeInteger;
exports.isNonpositiveInteger = isNonpositiveInteger;
exports.isNumberType = isNumberType;
exports.isOdd = isOdd;
exports.isPerCent = isPerCent;
exports.isPositiveInteger = isPositiveInteger;
exports.isRGB = isRGB;
exports.isUrl = isUrl;
exports.isWindows = isWindows;
exports.range = range;
var _FieldType = _interopRequireDefault(require("../_statics/FieldType"));
var _isArray = _interopRequireDefault(require("lodash/isArray"));
/**
 * @file Valid vendor
 */

// Statics

// Vendors

/**
 * @param value
 * @param min
 * @param max
 * @returns {*}
 */
function range(value, min, max) {
  max !== undefined && (value = value > max ? max : value);
  min !== undefined && (value = value < min ? min : value);
  return value;
}

/**
 * @returns {boolean}
 */
function isChrome() {
  return /chrome/i.test(navigator.userAgent);
}

/**
 * @returns {boolean}
 */
function isMac() {
  return /macintosh|mac os x/i.test(navigator.userAgent);
}

/**
 * @returns {boolean}
 */
function isWindows() {
  return /windows|win32/i.test(navigator.userAgent);
}

/**
 * @param value
 * @returns {boolean}
 */
function isInteger(value) {
  return /^(0|-?[0-9][1-9]*)$/.test(value);
}

/**
 * @param value
 * @returns {boolean}
 */
function isPositiveInteger(value) {
  return isInteger(value) && value > 0;
}

/**
 * @param value
 * @returns {boolean}
 */
function isNonnegativeInteger(value) {
  return isInteger(value) && value >= 0;
}

/**
 * @param value
 * @returns {boolean}
 */
function isNegativeInteger(value) {
  return isInteger(value) && value < 0;
}

/**
 * @param value
 * @returns {boolean}
 */
function isNonpositiveInteger(value) {
  return isInteger(value) && value <= 0;
}

/**
 * @param value
 * @returns {boolean}
 */
function isOdd(value) {
  return isInteger(value) && value % 2 === 1;
}

/**
 * @param value
 * @returns {boolean}
 */
function isEven(value) {
  return isInteger(value) && value % 2 === 0;
}

/**
 * @param value
 * @param min
 * @param max
 * @returns {boolean}
 */
function isInRange(value, min, max) {
  return !isNaN(value) && !isNaN(min) && !isNaN(max) && value >= min && value <= max;
}

/**
 * @param value
 * @returns {boolean}
 */
function isEmail(value) {
  return /^\w[-\w.+]*@([A-Za-z0-9][-A-Za-z0-9]+\.)+[A-Za-z]{2,14}$/.test(value);
}

/**
 * @param value
 * @returns {boolean}
 */
function isUrl(value) {
  return /^((https|http|ftp|rtsp|mms)?:\/\/)[^\s]+$/.test(value);
}

/**
 * @param perCent
 * @returns {boolean}
 */
function isPerCent(perCent) {
  return !isNaN(perCent) && perCent >= 0 && perCent <= 1;
}

/**
 * @param deg
 * @returns {boolean}
 */
function isDeg(deg) {
  return !isNaN(deg) && deg >= 0 && deg <= 360;
}

/**
 * @param rgb
 * @returns {*|boolean}
 */
function isRGB(rgb) {
  return rgb && (0, _isArray["default"])(rgb) && rgb.length === 3 && rgb.filter(function (item) {
    return item >= 0 && item <= 255;
  }).length === 3;
}

/**
 * @param hsb
 * @returns {*|boolean}
 */
function isHSB(hsb) {
  return hsb && (0, _isArray["default"])(hsb) && hsb.length === 3 && isDeg(hsb[0]) && isInRange(hsb[1], 0, 1) && isInRange(hsb[2], 0, 1);
}

/**
 * @param hex
 * @returns {boolean}
 */
function isHex(hex) {
  return /^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$/.test(hex);
}

/**
 * @param type
 * @returns {boolean}
 */
function isNumberType(type) {
  var NUMBER = _FieldType["default"].NUMBER,
    INTEGER = _FieldType["default"].INTEGER,
    POSITIVE_INTEGER = _FieldType["default"].POSITIVE_INTEGER,
    NONNEGATIVE_INTEGER = _FieldType["default"].NONNEGATIVE_INTEGER,
    NEGATIVE_INTEGER = _FieldType["default"].NEGATIVE_INTEGER,
    NONPOSITIVE_INTEGER = _FieldType["default"].NONPOSITIVE_INTEGER;
  return type === NUMBER || type === INTEGER || type === POSITIVE_INTEGER || type === NONNEGATIVE_INTEGER || type === NEGATIVE_INTEGER || type === NONPOSITIVE_INTEGER;
}

/* eslint-disable complexity */
/**
 * @param value
 * @param props
 * @returns {*[]}
 */
function fieldValid(value, props) {
  var type = props.type,
    required = props.required,
    maxLength = props.maxLength,
    max = props.max,
    min = props.min,
    pattern = props.pattern,
    patternInvalidMsg = props.patternInvalidMsg;
  var invalidMsgs = [];
  if (required === true && value === '') {
    invalidMsgs.push('Required');
  }
  if (type === _FieldType["default"].EMAIL && value && !isEmail(value)) {
    invalidMsgs.push('Invalid E-mail address');
  }
  if (type === _FieldType["default"].URL && value && !isUrl(value)) {
    invalidMsgs.push('Invalid url');
  }
  if (maxLength !== undefined && !isNaN(maxLength) && maxLength > 0 && value && value.length > maxLength) {
    invalidMsgs.push("Max length is ".concat(maxLength));
  }
  if (isNumberType(type) && value) {
    if (type === _FieldType["default"].NUMBER && isNaN(value)) {
      invalidMsgs.push('Not a valid number');
    }
    if (type === _FieldType["default"].INTEGER && !isInteger(value)) {
      invalidMsgs.push('Not a valid integer');
    }
    if (type === _FieldType["default"].POSITIVE_INTEGER && !isPositiveInteger(value)) {
      invalidMsgs.push('Not a valid positive integer');
    }
    if (type === _FieldType["default"].NONNEGATIVE_INTEGER && !isNonnegativeInteger(value)) {
      invalidMsgs.push('Not a valid nonnegative integer');
    }
    if (type === _FieldType["default"].NEGATIVE_INTEGER && !isNegativeInteger(value)) {
      invalidMsgs.push('Not a valid negative integer');
    }
    if (type === _FieldType["default"].NONPOSITIVE_INTEGER && !isNonpositiveInteger(value)) {
      invalidMsgs.push('Not a valid nonpositive integer');
    }
    if (max !== undefined && value > max) {
      invalidMsgs.push("Maximum value is ".concat(max));
    }
    if (min !== undefined && value < min) {
      invalidMsgs.push("Minimum value is ".concat(min));
    }
  }
  if (pattern !== undefined && !pattern.test(value)) {
    invalidMsgs.push(patternInvalidMsg);
  }
  return invalidMsgs;
}
var _default = {
  range: range,
  isChrome: isChrome,
  isMac: isMac,
  isWindows: isWindows,
  isInteger: isInteger,
  isPositiveInteger: isPositiveInteger,
  isNonnegativeInteger: isNonnegativeInteger,
  isNegativeInteger: isNegativeInteger,
  isNonpositiveInteger: isNonpositiveInteger,
  isOdd: isOdd,
  isEven: isEven,
  isInRange: isInRange,
  isEmail: isEmail,
  isUrl: isUrl,
  isPerCent: isPerCent,
  isDeg: isDeg,
  isRGB: isRGB,
  isHSB: isHSB,
  isHex: isHex,
  isNumberType: isNumberType,
  fieldValid: fieldValid
};
exports["default"] = _default;